#[non_exhaustive]pub enum ZarrMatrixError {
InvalidRank(usize),
SizeOverflow,
Array(Box<ArrayError>),
}Expand description
Failure to interpret or read a Zarr matrix.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidRank(usize)
The array has a rank other than two.
SizeOverflow
A dimension or decoded chunk cannot be represented in addressable memory.
Array(Box<ArrayError>)
The element type is incompatible, or Zarr data could not be read or decoded.